@@ -9,6 +9,7 @@
 /*                                                             */
 /***************************************************************/
 
+#define _XOPEN_SOURCE
 #include "config.h"
 
 #include <stdio.h>
@@ -21,6 +22,7 @@
 
 #ifdef REM_USE_WCHAR
 #include <wctype.h>
+#include <wchar.h>
 #endif
 
 #include "types.h"
@@ -356,6 +358,7 @@ static int make_wchar_versions(CalEntry *e)
     if (!buf) return 0;
 
     (void) mbstowcs(buf, e->text, len+1);
+    buf[len] = 0;
     e->wc_text = buf;
     e->wc_pos = buf;
     return 1;
@@ -881,11 +884,21 @@ static void PrintCentered(char const *s, int width, char *pad)
 
     for (i=0; i<d; i++) fputs(pad, stdout);
     for (i=0; i<width; i++) {
-	if (*s) PutChar(*s++); else break;
+	if (*s) {
+            if (isspace(*s)) {
+                PutChar(' ');
+                s++;
+            } else {
+                PutChar(*s++);
+            }
+        } else {
+            break;
+        }
     }
     for (i=d+len; i<width; i++) fputs(pad, stdout);
 #else
     size_t len = mbstowcs(NULL, s, 0);
+    int display_len;
     int i;
     wchar_t static_buf[128];
     wchar_t *buf;
@@ -909,11 +922,25 @@ static void PrintCentered(char const *s, int width, char *pad)
 	}
     }
     (void) mbstowcs(buf, s, len+1);
-    d = (width - len) / 2;
+    display_len = wcswidth(buf, len+1);
+    d = (width - display_len) / 2;
+    if (d < 0) d = 0;
     ws = buf;
     for (i=0; i<d; i++) fputs(pad, stdout);
     for (i=0; i<width; i++) {
-	if (*ws) PutWideChar(*ws++); else break;
+	if (*ws) {
+            PutWideChar(*ws++);
+            if (wcwidth(*ws) == 0) {
+                /* Don't count this character... it's zero-width */
+                i--;
+            }
+        } else {
+            break;
+        }
+    }
+    /* Mop up any potential combining characters */
+    while (*ws && wcwidth(*ws) == 0) {
+        PutWideChar(*ws++);
     }
     for (i=d+len; i<width; i++) fputs(pad, stdout);
     if (buf != static_buf) free(buf);
@@ -967,6 +994,7 @@ static int WriteOneColLine(int col)
 #ifdef REM_USE_WCHAR
     wchar_t const *ws;
     wchar_t const *wspace;
+    int width;
 #endif
 
     int numwritten = 0;
@@ -991,9 +1019,18 @@ static int WriteOneColLine(int col)
 	}
 
 	/* Find the last space char within the column. */
-	while (ws - e->wc_pos <= ColSpaces) {
-	    if (!*ws) {wspace = ws; break;}
-	    if (iswspace(*ws)) wspace = ws;
+        width = 0;
+	while (width <= ColSpaces) {
+	    if (!*ws) {
+                wspace = ws;
+                break;
+            }
+	    if (iswspace(*ws)) {
+                wspace = ws;
+            }
+            if (wcwidth(*ws)) {
+                width++;
+            }
 	    ws++;
 	}
 
@@ -1006,16 +1043,30 @@ static int WriteOneColLine(int col)
 	if (!wspace) {
 	    for (ws = e->wc_pos; ws - e->wc_pos < ColSpaces; ws++) {
 		if (!*ws) break;
-		numwritten++;
-		PutWideChar(*ws);
+                if (iswspace(*ws)) {
+                    PutChar(' ');
+                    numwritten++;
+                } else {
+                    if (wcwidth(*ws) > 0) {
+                        numwritten += wcwidth(*ws);
+                    }
+                    PutWideChar(*ws);
+                }
 	    }
 	    e->wc_pos = ws;
 	} else {
 	    /* We found a space - print everything before it. */
 	    for (ws = e->wc_pos; ws<wspace; ws++) {
 		if (!*ws) break;
-		numwritten++;
-		PutWideChar(*ws);
+                if (iswspace(*ws)) {
+                    PutChar(' ');
+                    numwritten++;
+                } else {
+                    if (wcwidth(*ws) > 0) {
+                        numwritten += wcwidth(*ws);
+                    }
+                    PutWideChar(*ws);
+                }
 	    }
 	}
 
@@ -1065,7 +1116,7 @@ static int WriteOneColLine(int col)
 	/* Find the last space char within the column. */
 	while (s - e->pos <= ColSpaces) {
 	    if (!*s) {space = s; break;}
-	    if (*s == ' ') space = s;
+	    if (isspace(*s)) space = s;
 	    s++;
 	}
 
@@ -1079,7 +1130,11 @@ static int WriteOneColLine(int col)
 	    for (s = e->pos; s - e->pos < ColSpaces; s++) {
 		if (!*s) break;
 		numwritten++;
-		PutChar(*s);
+                if (isspace(*s)) {
+                    PutChar(' ');
+                } else {
+                    PutChar(*s);
+                }
 	    }
 	    e->pos = s;
 	} else {
@@ -1087,7 +1142,11 @@ static int WriteOneColLine(int col)
 	    for (s = e->pos; s<space; s++) {
 		if (!*s) break;
 		numwritten++;
-		PutChar(*s);
+                if (isspace(*s)) {
+                    PutChar(' ');
+                } else {
+                    PutChar(*s);
+                }
 	    }
 	}
 
@@ -1100,7 +1159,7 @@ static int WriteOneColLine(int col)
 	while(numwritten++ < ColSpaces) PutChar(' ');
 
 	/* Skip any spaces before next word */
-	while (*s == ' ') s++;
+	while (isspace(*s)) s++;
 
 	/* If done, free memory if no next entry. */
 	if (!*s && !e->next) {
@@ -1325,6 +1384,9 @@ static int DoCalRem(ParsePtr p, int col)
     if (trig.typ == SAT_TYPE) {
 	r=DoSatRemind(&trig, &tim, p);
 	if (r) {
+            if (r == E_CANT_TRIG && trig.maybe_uncomputable) {
+                r = OK;
+            }
 	    FreeTrig(&trig);
 	    if (r == E_EXPIRED) return OK;
 	    return r;
@@ -1369,6 +1431,9 @@ static int DoCalRem(ParsePtr p, int col)
 	/* Calculate the trigger date */
 	jul = ComputeTrigger(trig.scanfrom, &trig, &tim, &r, 1);
 	if (r) {
+            if (r == E_CANT_TRIG && trig.maybe_uncomputable) {
+                r = OK;
+            }
 	    FreeTrig(&trig);
 	    return r;
 	}
@@ -1599,6 +1664,7 @@ static int DoCalRem(ParsePtr p, int col)
 	if(!e->filename) {
 	    if (e->text) free(e->text);
 	    if (e->raw_text) free(e->raw_text);
+            if (e->wc_text) free(e->wc_text);
 	    free(e);
 	    return E_NO_MEM;
 	}
