@@ -5,7 +5,7 @@
 /*  Print a PostScript calendar.                               */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2020 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2021 by Dianne Skoll                    */
 /*                                                             */
 /***************************************************************/
 
@@ -99,6 +99,7 @@ CalEntry *CurEntries = NULL;
 CalEntry *PsEntries[32];
 PageType *CurPage;
 char PortraitMode;
+char DaynumRight;
 char NoSmallCal;
 char UseISO;
 
@@ -140,6 +141,18 @@ void WriteOneEntry (CalEntry *c);
 void GetSmallLocations (void);
 char const *EatToken(char const *in, char *out, int maxlen);
 
+static void
+put_escaped_string(char const *s)
+{
+    while(*s) {
+        if (*s == '\\' || *s == '(' || *s == ')') {
+            PutChar('\\');
+        }
+        PutChar(*s);
+        s++;
+    }
+}
+
 /***************************************************************/
 /*                                                             */
 /*  StrCmpi                                                    */
@@ -336,7 +349,7 @@ int main(int argc, char *argv[])
 	    !strcmp(DBufValue(&buf), PSBEGIN2)) {
 	    if (!validfile) {
 		if (Verbose) {
-		    fprintf(stderr, "Rem2PS: Version %s Copyright 1992-2020 by Dianne Skoll\n\n", VERSION);
+		    fprintf(stderr, "Rem2PS: Version %s Copyright 1992-2021 by Dianne Skoll\n\n", VERSION);
 		    fprintf(stderr, "Generating PostScript calendar\n");
 		}
 	    }
@@ -587,6 +600,12 @@ void WriteProlog(void)
     printf("%%%%Pages: (atend)\n");
     printf("%%%%Orientation: %s\n", PortraitMode ? "Portrait" : "Landscape");
     printf("%%%%EndComments\n");
+    if (PortraitMode) {
+        printf("<< /PageSize [%d %d] >> setpagedevice\n", x, y);
+    } else {
+        /* They were swapped up above, so swap them back or we'll get rotated output */
+        printf("<< /PageSize [%d %d] >> setpagedevice\n", y, x);
+    }
 
     for (i=0; PSProlog1[i]; i++) puts(PSProlog1[i]);
     if (!MondayFirst)
@@ -679,7 +698,7 @@ void WriteCalEntry(void)
     printf("]\n");
 
 /* Print the day number */
-    printf("(%d)\n", CurDay);
+    printf("(%d) %d\n", CurDay, (int) DaynumRight);
 /* Do it! */
     printf("DoCalBox\n");
 
@@ -819,6 +838,7 @@ void Init(int argc, char *argv[])
     FillPage = 0;
     MondayFirst = 0;
     SmallLocation = "bt";
+    DaynumRight = 1;
 
     for(j=0; j<32; j++) PsEntries[i] = NULL;
 
@@ -935,6 +955,7 @@ void Init(int argc, char *argv[])
 
 	case 'i': UseISO = 1; break;
 
+        case 'x': DaynumRight = 0; break;
 	case 'c': k=(*s);
 	    if (!k) {
 		SmallLocation = SmallCalLoc[0];
@@ -979,6 +1000,7 @@ void Usage(char const *s)
     fprintf(stderr, "-b size       Set border size for calendar entries\n");
     fprintf(stderr, "-t size       Set line thickness\n");
     fprintf(stderr, "-e            Make calendar fill entire page\n");
+    fprintf(stderr, "-x            Put day numbers on left instead of right\n");
     fprintf(stderr, "-o[lrtb] marg Specify left, right, top and bottom margins\n");
     exit(1);
 }
@@ -1054,10 +1076,10 @@ int DoQueuedPs(void)
     FILE *fp;
     int fnoff;
     char buffer[512];
-    char const *size, *extra;
+    char fbuffer[512];
+    char const *size, *fsize, *extra;
     char const *s;
     int num, r, g, b, phase, fontsize, moonsize;
-    unsigned char c;
 
     if (!MondayFirst) begin = CurDay - WkDayNum;
     else		     begin = CurDay - (WkDayNum ? WkDayNum-1 : 6);
@@ -1129,19 +1151,28 @@ int DoQueuedPs(void)
 		while(*s && isspace(*s)) {
 		    s++;
 		}
-		while(*s) {
-		    if (*s == '\\' || *s == '(' || *s == ')') {
-			PutChar('\\');
-		    }
-		    PutChar(*s);
-		    s++;
-		}
+                put_escaped_string(s);
 		printf(") show grestore\n");
 		break;
 
 	    case SPECIAL_MOON:		/* Moon phase */
 		num = sscanf(e->entry+fnoff, "%d %d %d", &phase, &moonsize,
 			     &fontsize);
+		/* See if we have extra stuff */
+		extra = e->entry+fnoff;
+
+		/* Skip phase */
+		while(*extra && !isspace(*extra)) extra++;
+		while(*extra && isspace(*extra)) extra++;
+
+		/* Skip moon size */
+		while(*extra && !isspace(*extra)) extra++;
+		while(*extra && isspace(*extra)) extra++;
+
+		/* Skip font size */
+		while(*extra && !isspace(*extra)) extra++;
+		while(*extra && isspace(*extra)) extra++;
+
 		if (num == 1) {
 		    moonsize = -1;
 		    fontsize = -1;
@@ -1163,7 +1194,27 @@ int DoQueuedPs(void)
 		    size = buffer;
 		}
 
-		printf("gsave 0 setgray newpath Border %s add BoxHeight Border sub %s sub\n", size, size);
+                /* Store the starting X coordinate in "moonstartx" */
+                if (DaynumRight) {
+                    printf("Border %s add /moonstartx exch def", size);
+                } else {
+                    printf("xincr Border sub %s sub ", size);
+                    if (*extra) {
+                        if (fontsize < 0) {
+                            fsize = "EntrySize";
+                        } else {
+                            sprintf(fbuffer, "%d", fontsize);
+                            fsize = fbuffer;
+                        }
+                        printf("/EntryFont findfont %s scalefont setfont (",
+                               fsize);
+                        put_escaped_string(extra);
+                        printf(") stringwidth pop sub Border sub ");
+                    }
+                    printf("/moonstartx exch def\n");
+                }
+                printf(" gsave 0 setgray newpath ");
+                printf("moonstartx BoxHeight Border sub %s sub\n", size);
 		printf(" %s 0 360 arc closepath\n", size);
 		switch(phase) {
 		case 0:
@@ -1174,49 +1225,28 @@ int DoQueuedPs(void)
 		    break;
 
 		case 1:
-		    printf("stroke\n");
-		    printf("newpath Border %s add BoxHeight Border sub %s sub\n",
-			   size, size);
+		    printf("stroke\nnewpath ");
+                    printf("moonstartx BoxHeight Border sub %s sub\n", size);
 		    printf("%s 90 270 arc closepath fill\n", size);
 		    break;
 		default:
-		    printf("stroke\n");
-		    printf("newpath Border %s add BoxHeight Border sub %s sub\n",
-		size, size);
+		    printf("stroke\nnewpath ");
+                    printf("moonstartx BoxHeight Border sub %s sub\n", size);
 		    printf("%s 270 90 arc closepath fill\n", size);
 		    break;
 		}
-		/* See if we have extra stuff */
-		extra = e->entry+fnoff;
-
-		/* Skip phase */
-		while(*extra && !isspace(*extra)) extra++;
-		while(*extra && isspace(*extra)) extra++;
-
-		/* Skip moon size */
-		while(*extra && !isspace(*extra)) extra++;
-		while(*extra && isspace(*extra)) extra++;
-
-		/* Skip font size */
-		while(*extra && !isspace(*extra)) extra++;
-		while(*extra && isspace(*extra)) extra++;
-
 		/* Anything left? */
 		if (*extra) {
-		    printf("Border %s add %s add Border add BoxHeight border sub %s sub %s sub moveto\n", size, size, size, size);
+                    printf("moonstartx %s add Border add BoxHeight border sub %s sub %s sub moveto\n", size, size, size);
 		    if (fontsize < 0) {
-			size = "EntrySize";
+			fsize = "EntrySize";
 		    } else {
-			sprintf(buffer, "%d", fontsize);
-			size = buffer;
+			sprintf(fbuffer, "%d", fontsize);
+			fsize = fbuffer;
 		    }
 		    printf("/EntryFont findfont %s scalefont setfont (",
-			   size);
-		    while(*extra) {
-			c = (unsigned char) *extra++;
-			if (c == '\\' || c == '(' || c == ')') PutChar('\\');
-			PutChar(c);
-		    }
+			   fsize);
+                    put_escaped_string(extra);
 		    printf(") show\n");
 
 		}
